BrowserStringParser (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class BrowserStringParser

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.BrowserStringParser

    public class BrowserStringParser

extends java.lang.Object

Parse a Selenium browser string to extract browserStartCommand if there is one.

Nested Class Summary
`class` | `BrowserStringParser.Result`

Constructor Summary
`BrowserStringParser()`

Method Summary
`BrowserStringParser.Result` | `parseBrowserStartCommand(java.lang.String browserIdentifier, java.lang.String userBrowserSpecification)` Returns the browser start command, if any, for the browser in the 'browserString' parameter.

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### BrowserStringParser

    public BrowserStringParser()

Method Detail

### parseBrowserStartCommand

    public BrowserStringParser.Result parseBrowserStartCommand(java.lang.String browserIdentifier,
                                                               java.lang.String userBrowserSpecification)

  Returns the browser start command, if any, for the browser in the 'browserString' parameter. If the browserString cannot be matched to the 'knownBrowser' parameter, an illegal argument exception is thrown.

  Parameters:
    `browserIdentifier` - a known browser identifier.
    `userBrowserSpecification` - the string sent by the client to identify the type of browser to start, e.g. *firefox
  Returns:
    Match result, never null.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.